# Agent Communication Protocol Python SDK

## Disclaimer

The current [MCP](https://modelcontextprotocol.io/) based implementation should be treated as temporary and exploratory. It's main purpose is to enable integration of various agents into the platform and to explore underlying protocols, transports and possible multi-agent patterns. In Q2 2025, we expect to rebuild the SDK from the ground up.

## Overview

The Agent Communication Protocol allows applications to use agents through a uniform interface. It is built on top of [Model Context Protocol](https://modelcontextprotocol.io/).
